# This file was auto-generated by Fern from our API Definition.

import typing

SrcAppHttpRoutesInboxHandleMessageIncomingMessageContentType = typing.Union[
    typing.Literal["text/plain", "application/json"], typing.Any
]
