# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.block_run_completed import BlockRunCompleted
from ...types.block_run_failed import BlockRunFailed
from ...types.block_run_started import BlockRunStarted
from ...types.block_state_updated import BlockStateUpdated
from ...types.workflow_run_completed import WorkflowRunCompleted
from ...types.workflow_run_failed import WorkflowRunFailed
from ...types.workflow_run_started import WorkflowRunStarted

WorkflowsRunWithConfigResponseZero = typing.Union[
    WorkflowRunStarted,
    WorkflowRunCompleted,
    WorkflowRunFailed,
    BlockRunStarted,
    BlockRunCompleted,
    BlockRunFailed,
    BlockStateUpdated,
]
