# This file was auto-generated by Fern from our API Definition.

import typing

from .source_sync_crawl_settings_input import SourceSyncCrawlSettingsInput
from .source_sync_google_drive_settings import SourceSyncGoogleDriveSettings
from .source_sync_notion_settings_input import SourceSyncNotionSettingsInput
from .source_sync_page_crawl_settings_input import SourceSyncPageCrawlSettingsInput
from .source_sync_sitemap_settings_input import SourceSyncSitemapSettingsInput
from .source_sync_website_settings import SourceSyncWebsiteSettings

SrcAppHttpRoutesDriveCreateDriveCrawlPayloadSourceSyncSettings = typing.Union[
    SourceSyncGoogleDriveSettings,
    SourceSyncNotionSettingsInput,
    SourceSyncCrawlSettingsInput,
    SourceSyncPageCrawlSettingsInput,
    SourceSyncSitemapSettingsInput,
    SourceSyncWebsiteSettings,
]
