# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_revision import AgentRevision
from .files_attribute import FilesAttribute
from .mention import Mention
from .src_app_http_routes_inbox_handle_message_incoming_message import SrcAppHttpRoutesInboxHandleMessageIncomingMessage
from .src_app_http_routes_inbox_handle_message_interaction_request_participants_item import (
    SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem,
)


class SrcAppHttpRoutesInboxHandleMessageInteractionRequest(UncheckedBaseModel):
    messages: typing.List[SrcAppHttpRoutesInboxHandleMessageIncomingMessage]
    participants: typing.List[SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem]
    history: typing.Optional[typing.List[SrcAppHttpRoutesInboxHandleMessageIncomingMessage]] = None
    files: typing.Optional[typing.List[FilesAttribute]] = None
    mentions: typing.Optional[typing.List[Mention]] = None
    ephemeral_agent_revision: typing.Optional[AgentRevision] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
