# This file was auto-generated by Fern from our API Definition.

import typing

from .ai_agent import AiAgent
from .scout_user import ScoutUser

SrcAppHttpRoutesInboxHandleMessageInteractionRequestParticipantsItem = typing.Union[ScoutUser, AiAgent]
