# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.kanban_view_settings_input import KanbanViewSettingsInput
from ...types.table_view_settings_input import TableViewSettingsInput

CreateViewRequestSettings = typing.Union[KanbanViewSettingsInput, TableViewSettingsInput]
