# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .collection_destination import CollectionDestination
from .mapping import Mapping
from .schedule import Schedule
from .sync_config_input_source_settings import SyncConfigInputSourceSettings


class SyncConfigInput(UncheckedBaseModel):
    source_settings: SyncConfigInputSourceSettings
    destination: CollectionDestination
    mapping: Mapping
    schedule: typing.Optional[Schedule] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
