# This file was auto-generated by Fern from our API Definition.

import typing

from .tool_config_resource import ToolConfigResource

AgentRevisionToolConfigValue = typing.Union[bool, typing.List[ToolConfigResource]]
