# This file was auto-generated by Fern from our API Definition.

import typing

ToolConfigResourceType = typing.Union[typing.Literal["tables", "workflow", "crawl", "file", "integration"], typing.Any]
