# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class SlackMessageRequest(UncheckedBaseModel):
    """
    Request model for posting a message to a Slack channel
    """

    channel_id: str
    text: str
    thread_id: typing.Optional[str] = None
    blocks: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = None
    username: typing.Optional[str] = None
    icon_url: typing.Optional[str] = None
    integration_id: typing.Optional[str] = None
    unfurl_links: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
