# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .filter_type import FilterType
from .notion_filter_by import NotionFilterBy


class NotionFilterOptions(UncheckedBaseModel):
    field: typing.Optional[NotionFilterBy] = pydantic.Field(default=None)
    """
    Filter by page URL or page title
    """

    operator: typing.Optional[FilterType] = pydantic.Field(default=None)
    """
    Comparison operator to user for filtering
    """

    value: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    List of values you want to filter by.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
