# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.slack_event_response import SlackEventResponse
from ...types.slack_url_verification import SlackUrlVerification

TriggersExecuteSlackResponse = typing.Union[SlackUrlVerification, SlackEventResponse]
