# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class QueryRequest(UncheckedBaseModel):
    """
    Query request - declarative filtering
    """

    type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Filter by entity type
    """

    filter: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Filter by data fields
    """

    tags: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Filter by tags (must have ALL specified tags)
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Max results
    """

    include_deleted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include soft-deleted entities
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
