# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .collection_config import CollectionConfig
from .legacy_identity import LegacyIdentity


class Collection(UncheckedBaseModel):
    collection_config: CollectionConfig
    last_updated_at: dt.datetime
    created_at: dt.datetime
    created_by: LegacyIdentity
    last_updated_by: LegacyIdentity
    collection_id: str
    revision_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
