# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .column_type import ColumnType
from .data_type import DataType
from .typescript_automation_config import TypescriptAutomationConfig


class ColumnTypeBase(UncheckedBaseModel):
    column_id: typing.Optional[str] = None
    column_display_name: typing.Optional[str] = None
    column_type: ColumnType
    data_type: DataType
    hidden: typing.Optional[bool] = None
    automation_config: TypescriptAutomationConfig = pydantic.Field()
    """
    Optional automation configuration to automatically calculate values for this column
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
