# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .block_output import BlockOutput
from .placeholder_output import PlaceholderOutput
from .workflow_note_output import WorkflowNoteOutput


class WorkflowConfigOutput(UncheckedBaseModel):
    workflow_display_name: typing.Optional[str] = None
    workflow_schema_version: typing.Optional[str] = None
    workflow_img_url: typing.Optional[str] = None
    workflow_description: typing.Optional[str] = None
    blocks: typing.Optional[typing.List[BlockOutput]] = None
    notes: typing.Optional[typing.List[WorkflowNoteOutput]] = None
    placeholders: typing.Optional[typing.List[PlaceholderOutput]] = None
    tags: typing.Optional[typing.List[str]] = None
    is_tool: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
