# This file was auto-generated by Fern from our API Definition.

import typing

FilterOperator = typing.Union[
    typing.Literal[
        "equals",
        "not_equals",
        "contains",
        "not_contains",
        "starts_with",
        "ends_with",
        "is_empty",
        "is_not_empty",
        "greater_than",
        "less_than",
        "greater_than_or_equal",
        "less_than_or_equal",
        "between",
        "in",
        "not_in",
        "date_is",
        "date_before",
        "date_after",
        "date_between",
        "date_is_empty",
        "date_is_not_empty",
        "is_true",
        "is_false",
    ],
    typing.Any,
]
