# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class Flags(UncheckedBaseModel):
    """
    On top of feature flags fetched from our port, we can also have other flags that
    are derived solely from business logic. This is where we would add those.
    """

    automation_columns: typing.Optional[bool] = None
    display_scout_organization_id: typing.Optional[bool] = None
    inbox_agent_trace: typing.Optional[bool] = None
    multi_player_chat: typing.Optional[bool] = None
    team_workspace: typing.Optional[bool] = None
    token_counts: typing.Optional[bool] = None
    drive_integrations: typing.Optional[bool] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
