# This file was auto-generated by Fern from our API Definition.

import typing

ColumnType = typing.Union[
    typing.Literal[
        "checkbox",
        "json",
        "number",
        "select",
        "multi-select",
        "text-long",
        "text-short",
        "datetime",
        "url",
        "markdown",
        "relation",
        "people",
    ],
    typing.Any,
]
