# This file was auto-generated by Fern from our API Definition.

import typing

from .cron_trigger_config import CronTriggerConfig
from .slack_trigger_config_output import SlackTriggerConfigOutput

TriggerTriggerConfig = typing.Union[CronTriggerConfig, SlackTriggerConfigOutput]
