# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .search_request_search_type import SearchRequestSearchType


class SearchRequest(UncheckedBaseModel):
    """
    Search request model
    """

    query: typing.Optional[str] = pydantic.Field(default=None)
    """
    Search query text
    """

    search_type: typing.Optional[SearchRequestSearchType] = pydantic.Field(default=None)
    """
    Type of search
    """

    filters: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Additional filters to apply
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum results to return
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
