# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class CreatePulseRequest(UncheckedBaseModel):
    action: typing.Optional[str] = None
    description: str
    agents: typing.List[typing.Dict[str, typing.Optional[typing.Any]]]
    objects: typing.Optional[typing.List[typing.Dict[str, typing.Optional[typing.Any]]]] = None
    context: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    tags: typing.Optional[typing.List[str]] = None
    visibility: typing.Optional[str] = None
    duration_minutes: typing.Optional[float] = None
    content: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = None
    text: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
