# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .single_page_crawler_settings_output import SinglePageCrawlerSettingsOutput
from .source_sync_page_crawl_settings_output_mode import SourceSyncPageCrawlSettingsOutputMode


class SourceSyncPageCrawlSettingsOutput(UncheckedBaseModel):
    source_archetype_id: typing.Literal["com.scoutos.page_crawl"] = "com.scoutos.page_crawl"
    start_urls: str = pydantic.Field()
    """
    The starting URL for the crawl process.
    """

    crawler_settings: typing.Optional[SinglePageCrawlerSettingsOutput] = None
    mode: typing.Optional[SourceSyncPageCrawlSettingsOutputMode] = pydantic.Field(default=None)
    """
    Merge: upsert documents keying off site url. Replace: merge and remove stale documents.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
