# This file was auto-generated by Fern from our API Definition.

import typing

from .kanban_view_input import KanbanViewInput
from .table_view_input import TableViewInput

CollectionViewStateInputViewsValue = typing.Union[KanbanViewInput, TableViewInput]
