# This file was auto-generated by Fern from our API Definition.

import typing

from .documents_update_batch_request_body_item_value import DocumentsUpdateBatchRequestBodyItemValue
from .documents_update_batch_request_body_one_value import DocumentsUpdateBatchRequestBodyOneValue
from .documents_update_batch_request_body_zero_value import DocumentsUpdateBatchRequestBodyZeroValue

DocumentsUpdateBatchRequestBody = typing.Union[
    typing.Dict[str, DocumentsUpdateBatchRequestBodyZeroValue],
    typing.Dict[str, typing.Optional[DocumentsUpdateBatchRequestBodyOneValue]],
    typing.List[typing.Dict[str, DocumentsUpdateBatchRequestBodyItemValue]],
    typing.List[typing.Dict[str, typing.Optional[DocumentsUpdateBatchRequestBodyItemValue]]],
]
