# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .public_copilot_config_code_theme import PublicCopilotConfigCodeTheme
from .public_copilot_config_fab_value import PublicCopilotConfigFabValue
from .public_copilot_config_mode import PublicCopilotConfigMode


class PublicCopilotConfig(UncheckedBaseModel):
    """
    Public copilot configuration without sensitive fields.
    """

    workflow_id: typing.Optional[str] = None
    img_url: typing.Optional[str] = None
    display_name: typing.Optional[str] = None
    mode: typing.Optional[PublicCopilotConfigMode] = None
    code_theme: typing.Optional[PublicCopilotConfigCodeTheme] = None
    colors: typing.Optional[typing.Dict[str, str]] = None
    fab: typing.Optional[typing.Dict[str, typing.Optional[PublicCopilotConfigFabValue]]] = None
    loading_text: typing.Optional[str] = None
    message_placeholder: typing.Optional[str] = None
    initial_activity: typing.Optional[typing.List[typing.Optional[typing.Any]]] = None
    powered_by: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
