# This file was auto-generated by Fern from our API Definition.

import typing

QueryBuilderRequestGroupByItem = typing.Union[
    typing.Literal["time_hour", "time_day", "time_week", "agent_type", "action_type", "tag_prefix"], typing.Any
]
