# This file was auto-generated by Fern from our API Definition.

import typing

from .kanban_view_output import KanbanViewOutput
from .table_view_output import TableViewOutput

ViewListResponseDataItem = typing.Union[KanbanViewOutput, TableViewOutput]
