# This file was auto-generated by Fern from our API Definition.

import typing

ConditionField = typing.Union[
    typing.Literal[
        "channel_id",
        "team_id",
        "user_id",
        "thread_id",
        "user_message",
        "is_first_message_in_thread",
        "channel_name",
        "bot_is_mentioned",
        "is_bot_message",
    ],
    typing.Any,
]
